guix-commits
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

01/01: gnu: guile-wm: Add '.desktop' file.


From: Ludovic Courtès
Subject: 01/01: gnu: guile-wm: Add '.desktop' file.
Date: Tue, 13 Sep 2016 12:01:34 +0000 (UTC)

civodul pushed a commit to branch master
in repository guix.

commit 23de5cbd1487747a2d690ee3ac7630142a7eaeb8
Author: Alex ter Weele <address@hidden>
Date:   Sun Sep 11 22:18:53 2016 -0400

    gnu: guile-wm: Add '.desktop' file.
    
    * gnu/packages/guile-wm.scm (guile-wm)[arguments]: Add
    'install-xsession' phase.
    
    Signed-off-by: Ludovic Courtès <address@hidden>
---
 gnu/packages/guile-wm.scm |   85 +++++++++++++++++++++++++++------------------
 1 file changed, 52 insertions(+), 33 deletions(-)

diff --git a/gnu/packages/guile-wm.scm b/gnu/packages/guile-wm.scm
index 98e657f..a114fd4 100644
--- a/gnu/packages/guile-wm.scm
+++ b/gnu/packages/guile-wm.scm
@@ -1,5 +1,6 @@
 ;;; GNU Guix --- Functional package management for GNU
 ;;; Copyright © 2013, 2014 Ludovic Courtès <address@hidden>
+;;; Copyright © 2016 Alex ter Weele <address@hidden>
 ;;;
 ;;; This file is part of GNU Guix.
 ;;;
@@ -64,6 +65,7 @@ dependencies.")
   (package
     (name "guile-wm")
     (version "1.0")
+    (synopsis "X11 window manager toolkit in Scheme")
     (source (origin
               (method url-fetch)
               (uri (string-append "http://www.markwitmer.com/dist/guile-wm-";
@@ -72,43 +74,60 @@ dependencies.")
                (base32
                 "1l9qcz236jxvryndimjy62cf8zxf8i3f8vg3zpqqjhw15j9mdk3r"))))
     (build-system gnu-build-system)
-    (arguments '(;; The '.scm' files go to $(datadir), so set that to the
-                 ;; standard value.
-                 #:configure-flags (list (string-append "--datadir="
-                                          (assoc-ref %outputs "out")
-                                          "/share/guile/site/2.0"))
-                 #:phases (alist-cons-before
-                           'configure 'set-go-directory
-                           (lambda* (#:key outputs #:allow-other-keys)
-                             ;; Install .go files to $out/share/guile/site/2.0.
-                             (let ((out (assoc-ref outputs "out")))
-                               (substitute* "module/Makefile.in"
-                                 (("^wmdir = .*$")
-                                  (string-append "wmdir = " out
-                                                 "/share/guile/site/2.0\n")))))
-                           (alist-cons-after
-                            'install 'set-load-path
-                            (lambda* (#:key inputs outputs #:allow-other-keys)
-                              ;; Put Guile-XCB's and Guile-WM's modules in the
-                              ;; search path of PROG.
-                              (let* ((out  (assoc-ref outputs "out"))
-                                     (prog (string-append out "/bin/guile-wm"))
-                                     (mods (string-append
-                                            out "/share/guile/site/2.0"))
-                                     (xcb  (string-append
-                                            (assoc-ref inputs "guile-xcb")
-                                            "/share/guile/site/2.0")))
-                                (wrap-program
-                                 prog
-                                 `("GUILE_LOAD_PATH" ":" prefix (,mods ,xcb))
-                                 `("GUILE_LOAD_COMPILED_PATH" ":" prefix
-                                   (,mods ,xcb)))))
-                            %standard-phases))))
+    (arguments
+     `( ;; The '.scm' files go to $(datadir), so set that to the
+       ;; standard value.
+       #:configure-flags (list (string-append "--datadir="
+                                              (assoc-ref %outputs "out")
+                                              "/share/guile/site/2.0"))
+       #:phases (alist-cons-before
+                 'configure 'set-go-directory
+                 (lambda* (#:key outputs #:allow-other-keys)
+                   ;; Install .go files to $out/share/guile/site/2.0.
+                   (let ((out (assoc-ref outputs "out")))
+                     (substitute* "module/Makefile.in"
+                       (("^wmdir = .*$")
+                        (string-append "wmdir = " out
+                                       "/share/guile/site/2.0\n")))))
+                 (alist-cons-after
+                  'install 'set-load-path
+                  (lambda* (#:key inputs outputs #:allow-other-keys)
+                    ;; Put Guile-XCB's and Guile-WM's modules in the
+                    ;; search path of PROG.
+                    (let* ((out  (assoc-ref outputs "out"))
+                           (prog (string-append out "/bin/guile-wm"))
+                           (mods (string-append
+                                  out "/share/guile/site/2.0"))
+                           (xcb  (string-append
+                                  (assoc-ref inputs "guile-xcb")
+                                  "/share/guile/site/2.0")))
+                      (wrap-program
+                          prog
+                        `("GUILE_LOAD_PATH" ":" prefix (,mods ,xcb))
+                        `("GUILE_LOAD_COMPILED_PATH" ":" prefix
+                          (,mods ,xcb)))))
+                  (alist-cons-after
+                   'install 'install-xsession
+                   (lambda* (#:key outputs #:allow-other-keys)
+                     ;; add a .desktop file to xsessions
+                     (let ((xsessions (string-append
+                                       %output "/share/xsessions")))
+                       (mkdir-p xsessions)
+                       (call-with-output-file (string-append
+                                               xsessions "/guile-wm.desktop")
+                         (lambda (port)
+                           (format port
+                                   "[Desktop Entry]~@
+                                    Name=~a~@
+                                    Comment=~a~@
+                                    Exec=~a/bin/guile-wm~@
+                                    Type=Application~%"
+                            ,name ,synopsis %output)))))
+                   %standard-phases)))))
     (native-inputs `(("pkg-config" ,pkg-config)))
     (inputs `(("guile" ,guile-2.0)
               ("guile-xcb" ,guile-xcb)))
     (home-page "http://www.markwitmer.com/guile-xcb/guile-wm.html";)
-    (synopsis "X11 window manager toolkit in Scheme")
     (description
      "Guile-WM is a simple window manager that's completely customizable—you
 have total control of what it does by choosing which modules to include.



reply via email to

[Prev in Thread] Current Thread [Next in Thread]